pub enum ConvertUnit<'a> {
Unit(&'a Arc<Unit>),
Key(&'a str),
}Expand description
Input unit for Converter::convert
Variants
Unit(&'a Arc<Unit>)
A unit directly
This is a small optimization when you already know the unit instance,
but ConvertUnit::Key will produce the same result with a fast
lookup.
Key(&'a str)
Any name, symbol or alias to a unit