pub struct Unit {
pub names: Vec<Arc<str>>,
pub symbols: Vec<Arc<str>>,
pub aliases: Vec<Arc<str>>,
pub ratio: f64,
pub difference: f64,
pub physical_quantity: PhysicalQuantity,
pub system: Option<System>,
}Expand description
A unit
Conversion will be val * [Self::ratio] + [Self::difference]
It implements Display. It will use Self::symbol or,
if alternate (#) is given, it will try the first name.
Fields
names: Vec<Arc<str>>All the names that may be used to format the unit
symbols: Vec<Arc<str>>All the symbols (abbreviations), like ml for millilitres
aliases: Vec<Arc<str>>Custom aliases to parse the unit from a different string
ratio: f64Conversion ratio
difference: f64Difference offset to the conversion ratio
physical_quantity: PhysicalQuantityThe PhysicalQuantity this unit belongs to
system: Option<System>The unit System this unit belongs to, if any
Implementations