Module error

Module error 

Error type, formatting and utilities.

Structs

PassResult
Output from the different passes of the parsing process
SourceDiag
A diagnostic of source code
SourceReport
Errors and warnings container with fancy formatting

Enums

Severity
Diagnostic severity
Stage
Stage where the diagnostic origined

Traits

Recover
Like Default but for situations where a default value does not make sense and we need to recover from an error.
RichError
Trait to enhace errors with rich metadata

Functions

write_rich_error
Writes a rich error report

Type Aliases

CowStr
Label
A label is a pair of a code location and an optional hint at that location