PassResult

Struct PassResult 

pub struct PassResult<T> { /* private fields */ }
Output from the different passes of the parsing process

Implementations

Source

impl<T> PassResult<T>

pub fn has_output(&self) -> bool

Check if the result has any output. It may not be valid.

pub fn report(&self) -> &SourceReport

Get the report

pub fn is_valid(&self) -> bool

Check if the result is valid.

If the result is invalid, the output, if any, should be discarded or used knowing that it contains errors or be incomplete.

pub fn output(&self) -> Option<&T>

Get the output

pub fn valid_output(&self) -> Option<&T>

Get the output only if it’s valid

pub fn into_result(self) -> Result<(T, SourceReport), SourceReport>

Transform into a common Rust Result

If the result is valid, the Ok variant holds the output and a report with only warnings. Otherwise Err holds a report with the errors (and warnings).

pub fn into_report(self) -> SourceReport

Transform into a SourceReport discarding the output

pub fn into_output(self) -> Option<T>

Transform into the output discarding errors/warnings

pub fn unwrap_output(self) -> T

Unwraps the inner output

Panics

If the output is None.

pub fn into_tuple(self) -> (Option<T>, SourceReport)

Get output, errors and warnings in a tuple

pub fn map<F, O>(self, f: F) -> PassResult<O>
where F: FnOnce(T) -> O,

Map the inner output