pub enum ComponentRelation {
Definition {
referenced_from: Vec<usize>,
defined_in_step: bool,
},
Reference {
references_to: usize,
},
}Expand description
Relation between components
Variants
Definition
The component is a definition
Fields
Reference
The component is a reference
Implementations
Sourceimpl ComponentRelation
impl ComponentRelation
Sourcepub fn referenced_from(&self) -> &[usize]
pub fn referenced_from(&self) -> &[usize]
Gets a list of the components referencing this one.
Returns a list of indices to the corresponding vec in Recipe.
Sourcepub fn references_to(&self) -> Option<usize>
pub fn references_to(&self) -> Option<usize>
Get the index the relations references to
Sourcepub fn is_reference(&self) -> bool
pub fn is_reference(&self) -> bool
Check if the relation is a reference
Sourcepub fn is_definition(&self) -> bool
pub fn is_definition(&self) -> bool
Check if the relation is a definition
Sourcepub fn is_defined_in_step(&self) -> Option<bool>
pub fn is_defined_in_step(&self) -> Option<bool>
Checks if the definition was in a step
Returns None for references