Error type, formatting and utilities.
Structs
- Pass
Result - Output from the different passes of the parsing process
- Source
Diag - A diagnostic of source code
- Source
Report - Errors and warnings container with fancy formatting
Enums
Traits
- Recover
- Like
Defaultbut for situations where a default value does not make sense and we need to recover from an error. - Rich
Error - Trait to enhace errors with rich metadata
Functions
- write_
rich_ error - Writes a rich error report