pub struct PassResult<T> { /* private fields */ }Expand description
Output from the different passes of the parsing process
Implementations
Sourceimpl<T> PassResult<T>
impl<T> PassResult<T>
Sourcepub fn has_output(&self) -> bool
pub fn has_output(&self) -> bool
Check if the result has any output. It may not be valid.
Sourcepub fn report(&self) -> &SourceReport
pub fn report(&self) -> &SourceReport
Get the report
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Check if the result is valid.
If the result is invalid, the output, if any, should be discarded or used knowing that it contains errors or be incomplete.
Sourcepub fn valid_output(&self) -> Option<&T>
pub fn valid_output(&self) -> Option<&T>
Get the output only if it’s valid
Sourcepub fn into_result(self) -> Result<(T, SourceReport), SourceReport>
pub fn into_result(self) -> Result<(T, SourceReport), SourceReport>
Sourcepub fn into_report(self) -> SourceReport
pub fn into_report(self) -> SourceReport
Transform into a SourceReport discarding the output
Sourcepub fn into_output(self) -> Option<T>
pub fn into_output(self) -> Option<T>
Transform into the output discarding errors/warnings
Sourcepub fn unwrap_output(self) -> T
pub fn unwrap_output(self) -> T
Sourcepub fn into_tuple(self) -> (Option<T>, SourceReport)
pub fn into_tuple(self) -> (Option<T>, SourceReport)
Get output, errors and warnings in a tuple
Sourcepub fn map<F, O>(self, f: F) -> PassResult<O>where
F: FnOnce(T) -> O,
pub fn map<F, O>(self, f: F) -> PassResult<O>where
F: FnOnce(T) -> O,
Map the inner output